@@ -27,6 +27,8 @@ This module provides a high-level API for BlueZ mesh stack.
 
 import asyncio
 import logging
+import socket
+import struct
 from enum import Enum
 from functools import lru_cache
 from os import urandom
@@ -62,6 +64,7 @@ from bluetooth_mesh.interfaces import (
     ProvisionerInterface,
 )
 from bluetooth_mesh.messages import AccessMessage
+from bluetooth_mesh.messages.fd import FdMessage, FdMessageType
 from bluetooth_mesh.models import ConfigClient, ModelConfig
 from bluetooth_mesh.tokenring import TokenRing
 from bluetooth_mesh.utils import MeshError, ParsedMeshMessage
@@ -547,7 +550,10 @@ class Application(
         self.elements = {}
 
     async def connect(
-        self, addr: Union[int, Callable[[], int], Awaitable[int]], iv_index: int = 0
+        self,
+        addr: Union[int, Callable[[], int], Awaitable[int]],
+        iv_index: int = 0,
+        **kwargs,
     ) -> Mapping[int, Dict[Tuple[int, int], Dict[str, Tuple[Any, int]]]]:
         """
         Connect to BlueZ. If a node doesn't exist yet, it gets created via
@@ -561,7 +567,7 @@ class Application(
         that yields a mesh address.
         """
         try:
-            configuration = await self.attach()
+            configuration = await self.attach(**kwargs)
         except (ValueError, dbus_next.errors.DBusError) as ex:
             self.logger.error("Attach failed: %s, trying to import node", ex)
             if isinstance(addr, Awaitable):
@@ -575,13 +581,13 @@ class Application(
                     "Address not given as a value or an acceptable callback."
                 )
             await self.import_node(addr=mesh_address, iv_index=iv_index)
-            configuration = await self.attach()
+            configuration = await self.attach(**kwargs)
 
-            # after importing, explicitly import own device key to enable
-            # communication with local Config Server
-            await self.management_interface.import_remote_node(
-                self.addr, len(self.ELEMENTS), self.dev_key
-            )
+        # after attaching, explicitly import own device key to enable
+        # communication with local Config Server
+        await self.management_interface.import_remote_node(
+            self.addr, len(self.ELEMENTS), self.dev_key
+        )
 
         return configuration
 
@@ -720,7 +726,9 @@ class Application(
         self.logger.info("Leave")
         await self.network_interface.leave(self.token_ring.token)
 
-    async def attach(self, token: Optional[int] = None):
+    async def attach(
+        self, token: Optional[int] = None, *, socket_pair=False, socket_path: str = None
+    ):
         """
         Attach to existing node using a token.
 
@@ -732,8 +740,28 @@ class Application(
         if token is None:
             raise ValueError("No token")
 
-        self.logger.info("Attach %x", token)
-        path, configuration = await self.network_interface.attach("/", token)
+        self.logger.info(
+            "Attach %x (socket_pair=%s, socket_path=%s)",
+            token,
+            socket_pair,
+            socket_path,
+        )
+
+        if socket_pair and socket_path:
+            raise AssertionError("Use either socket_pair or socket_path")
+
+        if socket_pair:
+            path, configuration, sock = await self.network_interface.attach_fd(
+                "/", token
+            )
+            self._add_reader(sock)
+        elif socket_path:
+            path, configuration, sock = await self.network_interface.attach_unix(
+                "/", token, socket_path
+            )
+            self._add_reader(sock)
+        else:
+            path, configuration = await self.network_interface.attach("/", token)
 
         self.token_ring.token = token
 
@@ -760,6 +788,36 @@ class Application(
 
         return configuration
 
+    def _add_reader(self, sock: Any) -> Any:
+        HEADER = struct.Struct("<BHB20s")
+        NETKEY_PARAMS = struct.Struct("<H?17x")
+        APPKEY_PARAMS = struct.Struct("<HH16s")
+
+        def _read_message() -> Any:
+            while True:
+                try:
+                    line, *_ = sock.recvmsg(1024)
+                except BlockingIOError:
+                    break
+
+                header, data = line[: HEADER.size], line[HEADER.size :]
+                element, source, type, params = HEADER.unpack(header)
+
+                if type == FdMessageType.NETKEY:
+                    net_index, remote = NETKEY_PARAMS.unpack(params)
+
+                    self.elements[element].dev_key_message_received(
+                        source, remote, net_index, data
+                    )
+                elif type == FdMessageType.APPKEY:
+                    app_index, destination, label = APPKEY_PARAMS.unpack(params)
+
+                    self.elements[element].message_received(
+                        source, app_index, destination, data
+                    )
+
+        self.loop.add_reader(sock, _read_message)
+
     async def import_node(
         self,
         dev_key: Optional[DeviceKey] = None,
