@@ -1,12 +1,53 @@
-from math import pow, log
-from construct import (
-    Int8sl, Int8ul, Int16ul, Int16sl, Int24ul, Int32ul, Struct, Embedded,
-    Switch, this, Adapter, Probe, Flag, Array, Byte, BytesInteger, BitsInteger, PaddedString
-)
+#
+# python-bluetooth-mesh - Bluetooth Mesh for Python
+#
+# Copyright (C) 2019  SILVAIR sp. z o.o.
+#
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#
+#
+# pylint: disable=W0223
+
 from datetime import datetime, timedelta
+from enum import IntEnum
+from math import log, pow
+
+from construct import (
+    Adapter,
+    Array,
+    BitsInteger,
+    Byte,
+    BytesInteger,
+    Embedded,
+    Flag,
+    Int8sl,
+    Int8ul,
+    Int16sl,
+    Int16ul,
+    Int24ul,
+    Int32ul,
+    PaddedString,
+    Probe,
+    Struct,
+    Switch,
+    this,
+)
+
 from bluetooth_mesh.messages.config import EmbeddedBitStruct
 from bluetooth_mesh.messages.util import DefaultCountValidator
-from enum import IntEnum
 
 
 class PropertyID(IntEnum):
@@ -123,6 +164,9 @@ class PropertyID(IntEnum):
     TOTAL_LIGHT_EXPOSURE_TIME = 0x006F
     TOTAL_LUMINOUS_ENERGY = 0x0070
 
+    def __repr__(self):
+        return str(self.value)
+
 
 class TimeExponential8Validator(Adapter):
     def _decode(self, obj, content, path):
@@ -142,6 +186,13 @@ class DateValidator(Adapter):
         return 0x0 if obj is None else (obj - self.EPOCH).days
 
 
+def FixedString(size):
+    return PaddedString(size, "utf8")
+
+
+# fmt: off
+
+
 # time
 TimeMiliseconds24 = Struct(
     "seconds" / DefaultCountValidator(Int24ul, rounding=3, resolution=0.001)
@@ -418,126 +469,124 @@ RelativeRuntimeInAGenericLevelRange = Struct(
     "maximum_generic_level" / DefaultCountValidator(Int16ul),
 )
 
-
-def FixedString(size):
-    return PaddedString(size, "utf8")
-
+PropertyDict = {
+    PropertyID.AVERAGE_AMBIENT_TEMPERATURE_IN_A_PERIOD_OF_DAY: Temperature8InAPeriodOfDay,
+    PropertyID.AVERAGE_INPUT_CURRENT: AverageCurrent,
+    PropertyID.AVERAGE_INPUT_VOLTAGE: AverageVoltage,
+    PropertyID.AVERAGE_OUTPUT_CURRENT: AverageCurrent,
+    PropertyID.AVERAGE_OUTPUT_VOLTAGE: AverageVoltage,
+    PropertyID.CENTER_BEAM_INTENSITY_AT_FULL_POWER: LuminousIntensity,
+    PropertyID.CHROMATICITY_TOLERANCE: ChromaticityTolerance,
+    PropertyID.COLOR_RENDERING_INDEX_R9: ColorRenderingIndex,
+    PropertyID.COLOR_RENDERING_INDEX_RA: ColorRenderingIndex,
+    PropertyID.DEVICE_APPEARANCE: Appearance,
+    PropertyID.DEVICE_COUNTRY_OF_ORIGIN: CountryCode,
+    PropertyID.DEVICE_DATE_OF_MANUFACTURE: DateUTC,
+    PropertyID.DEVICE_ENERGY_USE_SINCE_TURN_ON: Energy,
+    PropertyID.DEVICE_FIRMWARE_REVISION: FixedString(8),
+    PropertyID.DEVICE_GLOBAL_TRADE_ITEM_NUMBER: GlobalTradeItemNumber,
+    PropertyID.DEVICE_HARDWARE_REVISION: FixedString(16),
+    PropertyID.DEVICE_MANUFACTURER_NAME: FixedString(36),
+    PropertyID.DEVICE_MODEL_NUMBER: FixedString(24),
+    PropertyID.DEVICE_OPERATING_TEMPERATURE_RANGE_SPECIFICATION: TemperatureRange,
+    PropertyID.DEVICE_OPERATING_TEMPERATURE_STATISTICAL_VALUES: TemperatureStatistics,
+    PropertyID.DEVICE_OVER_TEMPERATURE_EVENT_STATISTICS: EventStatistics,
+    PropertyID.DEVICE_POWER_RANGE_SPECIFICATION: PowerSpecification,
+    PropertyID.DEVICE_RUNTIME_SINCE_TURN_ON: TimeHour24,
+    PropertyID.DEVICE_RUNTIME_WARRANTY: TimeHour24,
+    PropertyID.DEVICE_SERIAL_NUMBER: FixedString(16),
+    PropertyID.DEVICE_SOFTWARE_REVISION: FixedString(8),
+    PropertyID.DEVICE_UNDER_TEMPERATURE_EVENT_STATISTICS: EventStatistics,
+    PropertyID.INDOOR_AMBIENT_TEMPERATURE_STATISTICAL_VALUES: Temperature8Statistics,
+    PropertyID.INITIAL_CIE_1931_CHROMATICITY_COORDINATES: ChromaticityCoordinates,
+    PropertyID.INITIAL_CORRELATED_COLOR_TEMPERATURE: CorrelatedColorTemperature,
+    PropertyID.INITIAL_LUMINOUS_FLUX: LuminousFlux,
+    PropertyID.INITIAL_PLANCKIAN_DISTANCE: ChromaticDistanceFromPlanckian,
+    PropertyID.INPUT_CURRENT_RANGE_SPECIFICATION: ElectricCurrentSpecification,
+    PropertyID.INPUT_CURRENT_STATISTICS: ElectricCurrentStatistics,
+    PropertyID.INPUT_OVER_CURRENT_EVENT_STATISTICS: EventStatistics,
+    PropertyID.INPUT_OVER_RIPPLE_VOLTAGE_EVENT_STATISTICS: EventStatistics,
+    PropertyID.INPUT_OVER_VOLTAGE_EVENT_STATISTICS: EventStatistics,
+    PropertyID.INPUT_UNDER_CURRENT_EVENT_STATISTICS: EventStatistics,
+    PropertyID.INPUT_UNDER_VOLTAGE_EVENT_STATISTICS: EventStatistics,
+    PropertyID.INPUT_VOLTAGE_RANGE_SPECIFICATION: VoltageRange,
+    PropertyID.INPUT_VOLTAGE_RIPPLE_SPECIFICATION: Percentage8,
+    PropertyID.INPUT_VOLTAGE_STATISTICS: VoltageStatistics,
+    PropertyID.LIGHT_CONTROL_AMBIENT_LUXLEVEL_ON: Illuminance,
+    PropertyID.LIGHT_CONTROL_AMBIENT_LUXLEVEL_PROLONG: Illuminance,
+    PropertyID.LIGHT_CONTROL_AMBIENT_LUXLEVEL_STANDBY: Illuminance,
+    PropertyID.LIGHT_CONTROL_LIGHTNESS_ON: PerceivedLightness,
+    PropertyID.LIGHT_CONTROL_LIGHTNESS_PROLONG: PerceivedLightness,
+    PropertyID.LIGHT_CONTROL_LIGHTNESS_STANDBY: PerceivedLightness,
+    PropertyID.LIGHT_CONTROL_REGULATOR_ACCURACY: Percentage8,
+    PropertyID.LIGHT_CONTROL_REGULATOR_KID: Coefficient,
+    PropertyID.LIGHT_CONTROL_REGULATOR_KIU: Coefficient,
+    PropertyID.LIGHT_CONTROL_REGULATOR_KPD: Coefficient,
+    PropertyID.LIGHT_CONTROL_REGULATOR_KPU: Coefficient,
+    PropertyID.LIGHT_CONTROL_TIME_FADE: TimeMiliseconds24,
+    PropertyID.LIGHT_CONTROL_TIME_FADE_ON: TimeMiliseconds24,
+    PropertyID.LIGHT_CONTROL_TIME_FADE_STANDBY_AUTO: TimeMiliseconds24,
+    PropertyID.LIGHT_CONTROL_TIME_FADE_STANDBY_MANUAL: TimeMiliseconds24,
+    PropertyID.LIGHT_CONTROL_TIME_OCCUPANCY_DELAY: TimeMiliseconds24,
+    PropertyID.LIGHT_CONTROL_TIME_PROLONG: TimeMiliseconds24,
+    PropertyID.LIGHT_CONTROL_TIME_RUN_ON: TimeMiliseconds24,
+    PropertyID.LUMEN_MAINTENANCE_FACTOR: Percentage8,
+    PropertyID.LUMINOUS_EFFICACY: LuminousEfficacy,
+    PropertyID.LUMINOUS_ENERGY_SINCE_TURN_ON: LuminousEnergy,
+    PropertyID.LUMINOUS_EXPOSURE: LuminousExposure,
+    PropertyID.LUMINOUS_FLUX_RANGE: LuminousFluxRange,
+    PropertyID.MOTION_SENSED: Percentage8,
+    PropertyID.MOTION_THRESHOLD: Percentage8,
+    PropertyID.OPEN_CIRCUIT_EVENT_STATISTICS: EventStatistics,
+    PropertyID.OUTDOOR_STATISTICAL_VALUES: Temperature8Statistics,
+    PropertyID.OUTPUT_CURRENT_RANGE: ElectricCurrentRange,
+    PropertyID.OUTPUT_CURRENT_STATISTICS: ElectricCurrentStatistics,
+    PropertyID.OUTPUT_RIPPLE_VOLTAGE_SPECIFICATION: Percentage8,
+    PropertyID.OUTPUT_VOLTAGE_RANGE: VoltageRange,
+    PropertyID.OUTPUT_VOLTAGE_STATISTICS: VoltageStatistics,
+    PropertyID.OVER_OUTPUT_RIPPLE_VOLTAGE_EVENT_STATISTICS: EventStatistics,
+    PropertyID.PEOPLE_COUNT: Count16,
+    PropertyID.PRESENCE_DETECTED: Presence,
+    PropertyID.PRESENT_AMBIENT_LIGHT_LEVEL: Illuminance,
+    PropertyID.PRESENT_AMBIENT_TEMPERATURE: Temperature8,
+    PropertyID.PRESENT_CIE_1931_CHROMATICITY_COORDINATES: ChromaticityCoordinates,
+    PropertyID.PRESENT_CORRELATED_COLOR_TEMPERATURE: CorrelatedColorTemperature,
+    PropertyID.PRESENT_DEVICE_INPUT_POWER: Power,
+    PropertyID.PRESENT_DEVICE_OPERATING_EFFICIENCY: Percentage8,
+    PropertyID.PRESENT_DEVICE_OPERATING_TEMPERATURE: Temperature,
+    PropertyID.PRESENT_ILLUMINANCE: Illuminance,
+    PropertyID.PRESENT_INDOOR_AMBIENT_TEMPERATURE: Temperature8,
+    PropertyID.PRESENT_INPUT_CURRENT: ElectricCurrent,
+    PropertyID.PRESENT_INPUT_RIPPLE_VOLTAGE: Percentage8,
+    PropertyID.PRESENT_INPUT_VOLTAGE: Voltage,
+    PropertyID.PRESENT_LUMINOUS_FLUX: LuminousFlux,
+    PropertyID.PRESENT_OUTDOOR_AMBIENT_TEMPERATURE: Temperature8,
+    PropertyID.PRESENT_OUTPUT_CURRENT: ElectricCurrent,
+    PropertyID.PRESENT_OUTPUT_VOLTAGE: Voltage,
+    PropertyID.PRESENT_PLANCKIAN_DISTANCE: ChromaticDistanceFromPlanckian,
+    PropertyID.PRESENT_RELATIVE_OUTPUT_RIPPLE_VOLTAGE: Percentage8,
+    PropertyID.RELATIVE_DEVICE_ENERGY_USE_IN_A_PERIOD_OF_DAY: EnergyInAPeriodOfDay,
+    PropertyID.RELATIVE_DEVICE_RUNTIME_IN_A_GENERIC_LEVEL_RANGE: RelativeRuntimeInAGenericLevelRange,
+    PropertyID.RELATIVE_EXPOSURE_TIME_IN_AN_ILLUMINANCE_RANGE: RelativeValueInAnIlluminanceRange,
+    PropertyID.RELATIVE_RUNTIME_IN_A_CORRELATED_COLOR_TEMPERATURE_RANGE: LuminousEnergy,
+    PropertyID.RELATIVE_RUNTIME_IN_A_DEVICE_OPERATING_TEMPERATURE_RANGE: RelativeValueInATemperatureRange,
+    PropertyID.RELATIVE_RUNTIME_IN_AN_INPUT_CURRENT_RANGE: RelativeValueInACurrentRange,
+    PropertyID.RELATIVE_RUNTIME_IN_AN_INPUT_VOLTAGE_RANGE: RelativeValueInAVoltageRange,
+    PropertyID.SHORT_CIRCUIT_EVENT_STATISTICS: EventStatistics,
+    PropertyID.TIME_SINCE_MOTION_SENSED: TimeSecond16,
+    PropertyID.TIME_SINCE_PRESENCE_DETECTED: TimeSecond16,
+    PropertyID.TOTAL_DEVICE_ENERGY_USE: Energy,
+    PropertyID.TOTAL_DEVICE_OFF_ON_CYCLES: Count24,
+    PropertyID.TOTAL_DEVICE_POWER_ON_CYCLES: Count24,
+    PropertyID.TOTAL_DEVICE_POWER_ON_TIME: TimeHour24,
+    PropertyID.TOTAL_DEVICE_RUNTIME: TimeHour24,
+    PropertyID.TOTAL_LIGHT_EXPOSURE_TIME: TimeHour24,
+    PropertyID.TOTAL_LUMINOUS_ENERGY: LuminousEnergy,
+}
 
 PropertyValue = Switch(
     this.sensor_setting_property_id,
-    {
-        PropertyID.AVERAGE_AMBIENT_TEMPERATURE_IN_A_PERIOD_OF_DAY: Temperature8InAPeriodOfDay,
-        PropertyID.AVERAGE_INPUT_CURRENT: AverageCurrent,
-        PropertyID.AVERAGE_INPUT_VOLTAGE: AverageVoltage,
-        PropertyID.AVERAGE_OUTPUT_CURRENT: AverageCurrent,
-        PropertyID.AVERAGE_OUTPUT_VOLTAGE: AverageVoltage,
-        PropertyID.CENTER_BEAM_INTENSITY_AT_FULL_POWER: LuminousIntensity,
-        PropertyID.CHROMATICITY_TOLERANCE: ChromaticityTolerance,
-        PropertyID.COLOR_RENDERING_INDEX_R9: ColorRenderingIndex,
-        PropertyID.COLOR_RENDERING_INDEX_RA: ColorRenderingIndex,
-        PropertyID.DEVICE_APPEARANCE: Appearance,
-        PropertyID.DEVICE_COUNTRY_OF_ORIGIN: CountryCode,
-        PropertyID.DEVICE_DATE_OF_MANUFACTURE: DateUTC,
-        PropertyID.DEVICE_ENERGY_USE_SINCE_TURN_ON: Energy,
-        PropertyID.DEVICE_FIRMWARE_REVISION: FixedString(8),
-        PropertyID.DEVICE_GLOBAL_TRADE_ITEM_NUMBER: GlobalTradeItemNumber,
-        PropertyID.DEVICE_HARDWARE_REVISION: FixedString(16),
-        PropertyID.DEVICE_MANUFACTURER_NAME: FixedString(36),
-        PropertyID.DEVICE_MODEL_NUMBER: FixedString(24),
-        PropertyID.DEVICE_OPERATING_TEMPERATURE_RANGE_SPECIFICATION: TemperatureRange,
-        PropertyID.DEVICE_OPERATING_TEMPERATURE_STATISTICAL_VALUES: TemperatureStatistics,
-        PropertyID.DEVICE_OVER_TEMPERATURE_EVENT_STATISTICS: EventStatistics,
-        PropertyID.DEVICE_POWER_RANGE_SPECIFICATION: PowerSpecification,
-        PropertyID.DEVICE_RUNTIME_SINCE_TURN_ON: TimeHour24,
-        PropertyID.DEVICE_RUNTIME_WARRANTY: TimeHour24,
-        PropertyID.DEVICE_SERIAL_NUMBER: FixedString(16),
-        PropertyID.DEVICE_SOFTWARE_REVISION: FixedString(8),
-        PropertyID.DEVICE_UNDER_TEMPERATURE_EVENT_STATISTICS: EventStatistics,
-        PropertyID.INDOOR_AMBIENT_TEMPERATURE_STATISTICAL_VALUES: Temperature8Statistics,
-        PropertyID.INITIAL_CIE_1931_CHROMATICITY_COORDINATES: ChromaticityCoordinates,
-        PropertyID.INITIAL_CORRELATED_COLOR_TEMPERATURE: CorrelatedColorTemperature,
-        PropertyID.INITIAL_LUMINOUS_FLUX: LuminousFlux,
-        PropertyID.INITIAL_PLANCKIAN_DISTANCE: ChromaticDistanceFromPlanckian,
-        PropertyID.INPUT_CURRENT_RANGE_SPECIFICATION: ElectricCurrentSpecification,
-        PropertyID.INPUT_CURRENT_STATISTICS: ElectricCurrentStatistics,
-        PropertyID.INPUT_OVER_CURRENT_EVENT_STATISTICS: EventStatistics,
-        PropertyID.INPUT_OVER_RIPPLE_VOLTAGE_EVENT_STATISTICS: EventStatistics,
-        PropertyID.INPUT_OVER_VOLTAGE_EVENT_STATISTICS: EventStatistics,
-        PropertyID.INPUT_UNDER_CURRENT_EVENT_STATISTICS: EventStatistics,
-        PropertyID.INPUT_UNDER_VOLTAGE_EVENT_STATISTICS: EventStatistics,
-        PropertyID.INPUT_VOLTAGE_RANGE_SPECIFICATION: VoltageRange,
-        PropertyID.INPUT_VOLTAGE_RIPPLE_SPECIFICATION: Percentage8,
-        PropertyID.INPUT_VOLTAGE_STATISTICS: VoltageStatistics,
-        PropertyID.LIGHT_CONTROL_AMBIENT_LUXLEVEL_ON: Illuminance,
-        PropertyID.LIGHT_CONTROL_AMBIENT_LUXLEVEL_PROLONG: Illuminance,
-        PropertyID.LIGHT_CONTROL_AMBIENT_LUXLEVEL_STANDBY: Illuminance,
-        PropertyID.LIGHT_CONTROL_LIGHTNESS_ON: PerceivedLightness,
-        PropertyID.LIGHT_CONTROL_LIGHTNESS_PROLONG: PerceivedLightness,
-        PropertyID.LIGHT_CONTROL_LIGHTNESS_STANDBY: PerceivedLightness,
-        PropertyID.LIGHT_CONTROL_REGULATOR_ACCURACY: Percentage8,
-        PropertyID.LIGHT_CONTROL_REGULATOR_KID: Coefficient,
-        PropertyID.LIGHT_CONTROL_REGULATOR_KIU: Coefficient,
-        PropertyID.LIGHT_CONTROL_REGULATOR_KPD: Coefficient,
-        PropertyID.LIGHT_CONTROL_REGULATOR_KPU: Coefficient,
-        PropertyID.LIGHT_CONTROL_TIME_FADE: TimeMiliseconds24,
-        PropertyID.LIGHT_CONTROL_TIME_FADE_ON: TimeMiliseconds24,
-        PropertyID.LIGHT_CONTROL_TIME_FADE_STANDBY_AUTO: TimeMiliseconds24,
-        PropertyID.LIGHT_CONTROL_TIME_FADE_STANDBY_MANUAL: TimeMiliseconds24,
-        PropertyID.LIGHT_CONTROL_TIME_OCCUPANCY_DELAY: TimeMiliseconds24,
-        PropertyID.LIGHT_CONTROL_TIME_PROLONG: TimeMiliseconds24,
-        PropertyID.LIGHT_CONTROL_TIME_RUN_ON: TimeMiliseconds24,
-        PropertyID.LUMEN_MAINTENANCE_FACTOR: Percentage8,
-        PropertyID.LUMINOUS_EFFICACY: LuminousEfficacy,
-        PropertyID.LUMINOUS_ENERGY_SINCE_TURN_ON: LuminousEnergy,
-        PropertyID.LUMINOUS_EXPOSURE: LuminousExposure,
-        PropertyID.LUMINOUS_FLUX_RANGE: LuminousFluxRange,
-        PropertyID.MOTION_SENSED: Percentage8,
-        PropertyID.MOTION_THRESHOLD: Percentage8,
-        PropertyID.OPEN_CIRCUIT_EVENT_STATISTICS: EventStatistics,
-        PropertyID.OUTDOOR_STATISTICAL_VALUES: Temperature8Statistics,
-        PropertyID.OUTPUT_CURRENT_RANGE: ElectricCurrentRange,
-        PropertyID.OUTPUT_CURRENT_STATISTICS: ElectricCurrentStatistics,
-        PropertyID.OUTPUT_RIPPLE_VOLTAGE_SPECIFICATION: Percentage8,
-        PropertyID.OUTPUT_VOLTAGE_RANGE: VoltageRange,
-        PropertyID.OUTPUT_VOLTAGE_STATISTICS: VoltageStatistics,
-        PropertyID.OVER_OUTPUT_RIPPLE_VOLTAGE_EVENT_STATISTICS: EventStatistics,
-        PropertyID.PEOPLE_COUNT: Count16,
-        PropertyID.PRESENCE_DETECTED: Presence,
-        PropertyID.PRESENT_AMBIENT_LIGHT_LEVEL: Illuminance,
-        PropertyID.PRESENT_AMBIENT_TEMPERATURE: Temperature8,
-        PropertyID.PRESENT_CIE_1931_CHROMATICITY_COORDINATES: ChromaticityCoordinates,
-        PropertyID.PRESENT_CORRELATED_COLOR_TEMPERATURE: CorrelatedColorTemperature,
-        PropertyID.PRESENT_DEVICE_INPUT_POWER: Power,
-        PropertyID.PRESENT_DEVICE_OPERATING_EFFICIENCY: Percentage8,
-        PropertyID.PRESENT_DEVICE_OPERATING_TEMPERATURE: Temperature,
-        PropertyID.PRESENT_ILLUMINANCE: Illuminance,
-        PropertyID.PRESENT_INDOOR_AMBIENT_TEMPERATURE: Temperature8,
-        PropertyID.PRESENT_INPUT_CURRENT: ElectricCurrent,
-        PropertyID.PRESENT_INPUT_RIPPLE_VOLTAGE: Percentage8,
-        PropertyID.PRESENT_INPUT_VOLTAGE: Voltage,
-        PropertyID.PRESENT_LUMINOUS_FLUX: LuminousFlux,
-        PropertyID.PRESENT_OUTDOOR_AMBIENT_TEMPERATURE: Temperature8,
-        PropertyID.PRESENT_OUTPUT_CURRENT: ElectricCurrent,
-        PropertyID.PRESENT_OUTPUT_VOLTAGE: Voltage,
-        PropertyID.PRESENT_PLANCKIAN_DISTANCE: ChromaticDistanceFromPlanckian,
-        PropertyID.PRESENT_RELATIVE_OUTPUT_RIPPLE_VOLTAGE: Percentage8,
-        PropertyID.RELATIVE_DEVICE_ENERGY_USE_IN_A_PERIOD_OF_DAY: EnergyInAPeriodOfDay,
-        PropertyID.RELATIVE_DEVICE_RUNTIME_IN_A_GENERIC_LEVEL_RANGE: RelativeRuntimeInAGenericLevelRange,
-        PropertyID.RELATIVE_EXPOSURE_TIME_IN_AN_ILLUMINANCE_RANGE: RelativeValueInAnIlluminanceRange,
-        PropertyID.RELATIVE_RUNTIME_IN_A_CORRELATED_COLOR_TEMPERATURE_RANGE: LuminousEnergy,
-        PropertyID.RELATIVE_RUNTIME_IN_A_DEVICE_OPERATING_TEMPERATURE_RANGE: RelativeValueInATemperatureRange,
-        PropertyID.RELATIVE_RUNTIME_IN_AN_INPUT_CURRENT_RANGE: RelativeValueInACurrentRange,
-        PropertyID.RELATIVE_RUNTIME_IN_AN_INPUT_VOLTAGE_RANGE: RelativeValueInAVoltageRange,
-        PropertyID.SHORT_CIRCUIT_EVENT_STATISTICS: EventStatistics,
-        PropertyID.TIME_SINCE_MOTION_SENSED: TimeSecond16,
-        PropertyID.TIME_SINCE_PRESENCE_DETECTED: TimeSecond16,
-        PropertyID.TOTAL_DEVICE_ENERGY_USE: Energy,
-        PropertyID.TOTAL_DEVICE_OFF_ON_CYCLES: Count24,
-        PropertyID.TOTAL_DEVICE_POWER_ON_CYCLES: Count24,
-        PropertyID.TOTAL_DEVICE_POWER_ON_TIME: TimeHour24,
-        PropertyID.TOTAL_DEVICE_RUNTIME: TimeHour24,
-        PropertyID.TOTAL_LIGHT_EXPOSURE_TIME: TimeHour24,
-        PropertyID.TOTAL_LUMINOUS_ENERGY: LuminousEnergy,
-    },
-    default=Array(this.length, Byte)
+        PropertyDict,
+        default=Array(this.length, Byte)
 )
+# fmt: off
